@@ -4,41 +4,41 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.101 qw(:Status );
-use IO::Compress::RawDeflate 2.101 ();
-use IO::Compress::Adapter::Deflate 2.101 ;
-use IO::Compress::Adapter::Identity 2.101 ;
-use IO::Compress::Zlib::Extra 2.101 ;
-use IO::Compress::Zip::Constants 2.101 ;
+use IO::Compress::Base::Common  2.103 qw(:Status );
+use IO::Compress::RawDeflate 2.103 ();
+use IO::Compress::Adapter::Deflate 2.103 ;
+use IO::Compress::Adapter::Identity 2.103 ;
+use IO::Compress::Zlib::Extra 2.103 ;
+use IO::Compress::Zip::Constants 2.103 ;
 
 use File::Spec();
 use Config;
 
-use Compress::Raw::Zlib  2.101 ();
+use Compress::Raw::Zlib  2.103 ();
 
 BEGIN
 {
     eval { require IO::Compress::Adapter::Bzip2 ;
-           IO::Compress::Adapter::Bzip2->import( 2.101 );
+           IO::Compress::Adapter::Bzip2->import( 2.103 );
            require IO::Compress::Bzip2 ;
-           IO::Compress::Bzip2->import( 2.101 );
+           IO::Compress::Bzip2->import( 2.103 );
          } ;
 
     eval { require IO::Compress::Adapter::Lzma ;
-           IO::Compress::Adapter::Lzma->import( 2.101 );
+           IO::Compress::Adapter::Lzma->import( 2.103 );
            require IO::Compress::Lzma ;
-           IO::Compress::Lzma->import( 2.101 );
+           IO::Compress::Lzma->import( 2.103 );
          } ;
 
     eval { require IO::Compress::Adapter::Xz ;
-           IO::Compress::Adapter::Xz->import( 2.101 );
+           IO::Compress::Adapter::Xz->import( 2.103 );
            require IO::Compress::Xz ;
-           IO::Compress::Xz->import( 2.101 );
+           IO::Compress::Xz->import( 2.103 );
          } ;
     eval { require IO::Compress::Adapter::Zstd ;
-           IO::Compress::Adapter::Zstd->import( 2.101 );
+           IO::Compress::Adapter::Zstd->import( 2.103 );
            require IO::Compress::Zstd ;
-           IO::Compress::Zstd->import( 2.101 );
+           IO::Compress::Zstd->import( 2.103 );
          } ;
 }
 
@@ -47,7 +47,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, %DEFLATE_CONSTANTS, $ZipError);
 
-$VERSION = '2.101';
+$VERSION = '2.103';
 $ZipError = '';
 
 @ISA = qw(IO::Compress::RawDeflate Exporter);
@@ -2121,9 +2121,9 @@ L<Archive::Tar|Archive::Tar>,
 L<IO::Zlib|IO::Zlib>
 
 For RFC 1950, 1951 and 1952 see
-L<http://www.faqs.org/rfcs/rfc1950.html>,
-L<http://www.faqs.org/rfcs/rfc1951.html> and
-L<http://www.faqs.org/rfcs/rfc1952.html>
+L<https://datatracker.ietf.org/doc/html/rfc1950>,
+L<https://datatracker.ietf.org/doc/html/rfc1951> and
+L<https://datatracker.ietf.org/doc/html/rfc1952>
 
 The I<zlib> compression library was written by Jean-loup Gailly
 C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
@@ -2143,7 +2143,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2021 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
