@@ -6,22 +6,22 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.101 qw(:Parse);
+use IO::Compress::Base::Common  2.103 qw(:Parse);
 
-use IO::Uncompress::Adapter::Inflate  2.101 ();
+use IO::Uncompress::Adapter::Inflate  2.103 ();
 
 
-use IO::Uncompress::Base  2.101 ;
-use IO::Uncompress::Gunzip  2.101 ;
-use IO::Uncompress::Inflate  2.101 ;
-use IO::Uncompress::RawInflate  2.101 ;
-use IO::Uncompress::Unzip  2.101 ;
+use IO::Uncompress::Base  2.103 ;
+use IO::Uncompress::Gunzip  2.103 ;
+use IO::Uncompress::Inflate  2.103 ;
+use IO::Uncompress::RawInflate  2.103 ;
+use IO::Uncompress::Unzip  2.103 ;
 
 require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $AnyInflateError);
 
-$VERSION = '2.101';
+$VERSION = '2.103';
 $AnyInflateError = '';
 
 @ISA = qw(IO::Uncompress::Base Exporter);
@@ -976,9 +976,9 @@ L<Archive::Tar|Archive::Tar>,
 L<IO::Zlib|IO::Zlib>
 
 For RFC 1950, 1951 and 1952 see
-L<http://www.faqs.org/rfcs/rfc1950.html>,
-L<http://www.faqs.org/rfcs/rfc1951.html> and
-L<http://www.faqs.org/rfcs/rfc1952.html>
+L<https://datatracker.ietf.org/doc/html/rfc1950>,
+L<https://datatracker.ietf.org/doc/html/rfc1951> and
+L<https://datatracker.ietf.org/doc/html/rfc1952>
 
 The I<zlib> compression library was written by Jean-loup Gailly
 C<gzip@prep.ai.mit.edu> and Mark Adler C<madler@alumni.caltech.edu>.
@@ -998,7 +998,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2021 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
